@@ -32,7 +32,7 @@ namespace Docky.Services
 		}
 		
 		public File AutoStartFile {
-			get { return FileFactory.NewForPath (Environment.GetFolderPath (Environment.SpecialFolder.ApplicationData)).GetChild ("autostart").GetChild ("docky.desktop"); }
+			get { return FileFactory.NewForPath (Environment.GetFolderPath (Environment.SpecialFolder.LocalApplicationData)).GetChild ("autostart").GetChild ("docky.desktop"); }
 		}
 	}
 }
