@@ -611,7 +611,8 @@ namespace Docky.Windowing
 					string vexec = null;
 					
 					if (exec.Contains (' ') &&
-						(exec.StartsWith ("ooffice") || exec.StartsWith ("openoffice") || exec.StartsWith ("soffice"))) {
+					    (exec.StartsWith ("ooffice") || exec.StartsWith ("openoffice") || exec.StartsWith ("soffice") ||
+					     exec.Contains ("/ooffice ") || exec.Contains ("/openoffice.org ") || exec.Contains ("/soffice "))) {
 						vexec = "ooffice" + exec.Split (' ') [1];
 					// for wine apps
 					} else if ((exec.Contains ("env WINEPREFIX=") && exec.Contains (" wine ")) ||
