@@ -558,7 +558,7 @@ namespace Docky.Interface
 		
 		int VisibleDockHeight {
 			get {
-				return ThreeDimensional ? (int) (0.4 * DockHeight) : DockHeight;
+				return ThreeDimensional ? (int) ((Preferences.PanelMode ? 0.33 : 0.4 ) * DockHeight) : DockHeight;
 			}
 		}
 		
@@ -2286,7 +2286,7 @@ namespace Docky.Interface
 				center = center.MoveIn (Position, move);
 			}
 			
-			double opacity = Math.Min (1, (render_time - item.AddTime).TotalMilliseconds / BaseAnimationTime.TotalMilliseconds);
+			double opacity = Math.Max (0, Math.Min (1, (render_time - item.AddTime).TotalMilliseconds / BaseAnimationTime.TotalMilliseconds));
 			opacity = Math.Pow (opacity, 2);
 			DockySurface icon;
 			
@@ -2686,11 +2686,12 @@ namespace Docky.Interface
 			}
 
 			using (Gdk.Pixmap pixmap = new Gdk.Pixmap (null, area.Width, area.Height, 1)) {
-				using (Context cr = Gdk.CairoHelper.Create (pixmap)) {
+				using (Cairo.Context cr = Gdk.CairoHelper.Create (pixmap)) {
 					cr.Color = new Cairo.Color (0, 0, 0, 1);
 					cr.Paint ();
 					
 					InputShapeCombineMask (pixmap, area.X, area.Y);
+					(cr.Target as IDisposable).Dispose ();
 				}
 			}
 		}
