@@ -92,14 +92,21 @@ class DockyBansheeItem(DockyItem):
 			else:
 				self.player = None
 				self.control = None
-				if self.timer > 0:
-					gobject.source_remove (self.timer)
-					self.timer = 0
+				self.stop_timer()
 				self.set_menu_buttons()
 				self.update_text()			
 				self.update_badge()
 				self.update_icon()
 	
+	def start_timer(self):
+		if not self.timer > 0:
+			self.timer = gobject.timeout_add (1000, self.update_badge)
+	
+	def stop_timer(self):
+		if self.timer > 0:
+			gobject.source_remove (self.timer)
+			self.timer = 0
+	
 	def init_banshee_objects(self):
 		obj = self.bus.get_object(bansheebus, playerpath)
 		self.player = dbus.Interface(obj, playeriface)
@@ -109,9 +116,9 @@ class DockyBansheeItem(DockyItem):
 		
 		if self.player:
 			self.update_songinfo()
-
-		if not self.timer > 0:
-			self.timer = gobject.timeout_add (1000, self.update_badge)
+		
+		if self.banshee_is_playing():
+			self.start_timer()
 
 	def clear_menu_buttons(self):
 		for k, v in self.id_map.iteritems():
@@ -150,6 +157,11 @@ class DockyBansheeItem(DockyItem):
 		print "StateChanged: %s" % (state)	
 		self.set_menu_buttons()
 		self.update_text()
+
+		if state == "playing":
+			self.start_timer()
+		else:
+			self.stop_timer()
 			
 	def update_songinfo(self):
 		if self.player:
@@ -263,35 +275,22 @@ class DockyBansheeItem(DockyItem):
 		return True
 	
 	def menu_pressed(self, menu_id):
+		if not self.player:
+			return False
+		
 		if self.id_map[menu_id] == "Play":
-			self.banshee_play()
+			self.player.Play()
 		elif self.id_map[menu_id] == "Pause":
-			self.banshee_pause()
+			self.player.Pause()
 		elif self.id_map[menu_id] == "Next":
-			self.banshee_next()
+			self.control.Next(False)
 		elif self.id_map[menu_id] == "Previous":
-			self.banshee_prev()
+			self.control.Previous(False)
 		
 	def add_menu_item(self, name, icon):
 		menu_id = self.iface.AddMenuItem(name, icon, "")
 		self.id_map[menu_id] = name
 		
-	def banshee_play(self):
-		if self.player:
-			self.player.Play()
-		
-	def banshee_pause(self):
-		if self.player:
-			self.player.Pause()
-	
-	def banshee_next(self):
-		if self.control:
-			self.control.Next(False)
-		
-	def banshee_prev(self):
-		if self.control:
-			self.control.Previous(False)
-		
 	def banshee_is_playing(self):
 		if self.player:
 			try:
